@@ -47,6 +47,7 @@ private slots:
 
     void removeOwnItems();
     void removeNotOwnedItems();
+    void removeNotOwnedItemsCancel();
     void removeFiles();
 
     void modifyItems();
@@ -64,6 +65,8 @@ private slots:
 
     void addItemsWhenFullOmitDeletingNotOwned();
 
+    void moveOwnItemsSortsBaseNames();
+
 private:
     TestInterfacePtr m_test;
 };
