@@ -42,7 +42,7 @@ public:
 signals:
     void clipboardChanged(const QVariantMap &data, ClipboardOwnership ownership);
     void clipboardUnchanged(const QVariantMap &data);
-    void synchronizeSelection(ClipboardMode sourceMode, const QString &text);
+    void synchronizeSelection(ClipboardMode sourceMode, const QString &text, uint targetTextHash);
 
 private:
     void onClipboardChanged(ClipboardMode mode);
