@@ -30,7 +30,6 @@
 
 namespace {
 
-const int bigMessageThreshold = 5 * 1024 * 1024;
 ClientSocketId lastSocketId = 0;
 
 const quint32 protocolMagicNumber = 0x0C090701;
@@ -80,9 +79,6 @@ bool writeMessage(QLocalSocket *socket, const QByteArray &msg)
 {
     COPYQ_LOG_VERBOSE( QString("Write message (%1 bytes).").arg(msg.size()) );
 
-    if (msg.size() > bigMessageThreshold)
-        COPYQ_LOG( QString("Sending big message: %1 MiB").arg(msg.size() / 1024 / 1024) );
-
     QDataStream out(socket);
     out.setVersion(QDataStream::Qt_5_0);
     // length is serialized as a quint32, followed by msg
@@ -168,7 +164,11 @@ bool ClientSocket::start()
 
     connect( m_socket.get(), &QLocalSocket::stateChanged,
              this, &ClientSocket::onStateChanged );
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
+    connect( m_socket.get(), &QLocalSocket::errorOccurred,
+#else
     connect( m_socket.get(), static_cast<void (QLocalSocket::*)(QLocalSocket::LocalSocketError)>(&QLocalSocket::error),
+#endif
              this, &ClientSocket::onError );
     connect( m_socket.get(), &QLocalSocket::readyRead,
              this, &ClientSocket::onReadyRead );
@@ -249,9 +249,6 @@ void ClientSocket::onReadyRead()
 
             m_message.remove(0, preambleSize);
             m_hasMessageLength = true;
-
-            if (m_messageLength > bigMessageThreshold)
-                COPYQ_LOG( QString("Receiving big message: %1 MiB").arg(m_messageLength / 1024 / 1024) );
         }
 
         const auto length = static_cast<int>(m_messageLength);
