@@ -39,6 +39,9 @@ namespace {
 
 const char propertyGeometryLockedUntilHide[] = "CopyQ_geometry_locked_until_hide";
 
+constexpr int windowMinWidth = 50;
+constexpr int windowMinHeight = 50;
+
 enum class GeometryAction {
     Save,
     Restore
@@ -131,30 +134,31 @@ QString resolutionTag(const QWidget &widget, GeometryAction geometryAction, bool
 
 void ensureWindowOnScreen(QWidget *widget, QPoint pos)
 {
-    const QSize size = widget->size();
-    const QRect availableGeometry = screenAvailableGeometry(pos);
-
+    const QSize size = widget->frameSize();
     int x = pos.x();
     int y = pos.y();
-    int w = size.width();
-    int h = size.height();
+    int w = qMax(windowMinWidth, size.width());
+    int h = qMax(windowMinHeight, size.height());
 
-    // Ensure that the window fits the screen, otherwise it may be moved
-    // to a neighboring screen.
-    w = qMin(w, availableGeometry.width());
-    h = qMin(h, availableGeometry.height());
+    const QRect availableGeometry = screenAvailableGeometry(pos);
+    if ( availableGeometry.isValid() ) {
+        // Ensure that the window fits the screen, otherwise it would be moved
+        // to a neighboring screen automatically.
+        w = qMin(w, availableGeometry.width());
+        h = qMin(h, availableGeometry.height());
 
-    if ( x + w > availableGeometry.right() )
-        x = availableGeometry.right() - w;
+        if ( x + w > availableGeometry.right() )
+            x = availableGeometry.right() - w;
 
-    if ( x < availableGeometry.left() )
-        x = availableGeometry.left();
+        if ( x < availableGeometry.left() )
+            x = availableGeometry.left();
 
-    if ( y + h > availableGeometry.bottom() )
-        y = availableGeometry.bottom() - h;
+        if ( y + h > availableGeometry.bottom() )
+            y = availableGeometry.bottom() - h;
 
-    if ( y < availableGeometry.top())
-        y = availableGeometry.top();
+        if ( y < availableGeometry.top())
+            y = availableGeometry.top();
+    }
 
     if ( size != QSize(w, h) ) {
         GEOMETRY_LOG( widget, QString::fromLatin1("Resize window: %1x%2").arg(w).arg(h) );
@@ -173,26 +177,37 @@ void ensureWindowOnScreen(QWidget *w)
     ensureWindowOnScreen(w, pos);
 }
 
-} // namespace
-
-QString getConfigurationFilePath(const char *suffix)
+QString getConfigurationFilePathHelper()
 {
     const QSettings settings(
                 QSettings::IniFormat, QSettings::UserScope,
                 QCoreApplication::organizationName(),
                 QCoreApplication::applicationName() );
-    QString path = settings.fileName();
+    return settings.fileName();
+}
+
+} // namespace
+
+const QString &getConfigurationFilePath()
+{
+    static const QString path = getConfigurationFilePathHelper();
+    return path;
+}
+
+QString getConfigurationFilePath(const char *suffix)
+{
+    QString path = getConfigurationFilePath();
     // Replace suffix.
     const int i = path.lastIndexOf(QLatin1Char('.'));
     Q_ASSERT(i != -1);
     Q_ASSERT( path.endsWith(QLatin1String(".ini")) );
-    return path.leftRef(i) + QLatin1String(suffix);
+    return path.left(i) + QLatin1String(suffix);
 }
 
-QString settingsDirectoryPath()
+const QString &settingsDirectoryPath()
 {
     static const QString path =
-        QDir::cleanPath( getConfigurationFilePath("") + QLatin1String("/..") );
+        QDir::cleanPath( getConfigurationFilePath() + QLatin1String("/..") );
     return path;
 }
 
@@ -222,8 +237,10 @@ void restoreWindowGeometry(QWidget *w, bool openOnCurrentScreen)
         // If geometry for the screen doesn't exist, move window to the middle of the screen.
         if (geometry.isEmpty()) {
             const QRect availableGeometry = screenAvailableGeometry(w->pos());
-            const QPoint position = availableGeometry.center() - w->rect().center();
-            w->move(position);
+            if ( availableGeometry.isValid() ) {
+                const QPoint position = availableGeometry.center() - w->rect().center();
+                w->move(position);
+            }
         }
     }
 
@@ -237,8 +254,10 @@ void restoreWindowGeometry(QWidget *w, bool openOnCurrentScreen)
                 windowHandle->setScreen(screen);
 
             const QRect availableGeometry = screen->availableGeometry();
-            const QPoint position = availableGeometry.center() - w->rect().center();
-            w->move(position);
+            if ( availableGeometry.isValid() ) {
+                const QPoint position = availableGeometry.center() - w->rect().center();
+                w->move(position);
+            }
         }
     }
 
