@@ -22,12 +22,33 @@
 #include "gui/screen.h"
 
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QPoint>
+#include <QScreen>
 #include <QStyle>
 #include <QWidget>
 #include <QWindow>
 
+namespace {
+
+QScreen *screenForWidget(QWidget *w)
+{
+    if (w) {
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+        if ( w->screen() )
+            return w->screen();
+#endif
+
+        const int i = screenNumberAt(w->pos());
+        const auto screens = QGuiApplication::screens();
+        if (0 <= i && i < screens.size())
+            return screens[i];
+    }
+
+    return QGuiApplication::primaryScreen();
+}
+
+} // namespace
+
 int smallIconSize()
 {
     return QApplication::style()->pixelMetric(QStyle::PM_SmallIconSize);
@@ -40,6 +61,9 @@ QPoint toScreen(QPoint pos, QWidget *w)
         window->setPosition(pos);
 
     const QRect availableGeometry = screenAvailableGeometry(pos);
+    if ( !availableGeometry.isValid() )
+        return pos;
+
     const QSize size = window ? window->size() : w->size();
     return QPoint(
                 qMax(availableGeometry.left(), qMin(pos.x(), availableGeometry.right() - size.width())),
@@ -47,7 +71,8 @@ QPoint toScreen(QPoint pos, QWidget *w)
                 );
 }
 
-int pointsToPixels(int points)
+int pointsToPixels(int points, QWidget *w)
 {
-    return points * QApplication::desktop()->physicalDpiX() / 72;
+    QScreen *screen = screenForWidget(w);
+    return static_cast<int>(points * screen->physicalDotsPerInchX() / 72.0);
 }
