@@ -17,25 +17,25 @@
     along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef MIMETYPES_H
-#define MIMETYPES_H
+#pragma once
+
+class QLatin1String;
 
 #define COPYQ_MIME_PREFIX "application/x-copyq-"
-extern const char mimeText[];
-extern const char mimeHtml[];
-extern const char mimeUriList[];
-extern const char mimeWindowTitle[];
-extern const char mimeItems[];
-extern const char mimeItemNotes[];
-extern const char mimeIcon[];
-extern const char mimeOwner[];
-extern const char mimeClipboardMode[];
-extern const char mimeCurrentTab[];
-extern const char mimeSelectedItems[];
-extern const char mimeCurrentItem[];
-extern const char mimeHidden[];
-extern const char mimeShortcut[];
-extern const char mimeColor[];
-extern const char mimeOutputTab[];
-
-#endif // MIMETYPES_H
+extern const QLatin1String mimeText;
+extern const QLatin1String mimeTextUtf8;
+extern const QLatin1String mimeHtml;
+extern const QLatin1String mimeUriList;
+extern const QLatin1String mimeWindowTitle;
+extern const QLatin1String mimeItems;
+extern const QLatin1String mimeItemNotes;
+extern const QLatin1String mimeIcon;
+extern const QLatin1String mimeOwner;
+extern const QLatin1String mimeClipboardMode;
+extern const QLatin1String mimeCurrentTab;
+extern const QLatin1String mimeSelectedItems;
+extern const QLatin1String mimeCurrentItem;
+extern const QLatin1String mimeHidden;
+extern const QLatin1String mimeShortcut;
+extern const QLatin1String mimeColor;
+extern const QLatin1String mimeOutputTab;
