@@ -66,14 +66,14 @@ public:
 
 signals:
     /** Emitted if dialog was accepted. */
-    void accepted(const Command &command, const QStringList &arguments, const QVariantMap &data);
+    void commandAccepted(const Command &command, const QStringList &arguments, const QVariantMap &data);
 
     void saveCommand(const Command &command);
 
 private:
     void onButtonBoxClicked(QAbstractButton* button);
     void onComboBoxCommandsCurrentIndexChanged(int index);
-    void onComboBoxInputFormatCurrentIndexChanged(const QString &format);
+    void onComboBoxInputFormatCurrentTextChanged(const QString &format);
     void onComboBoxOutputFormatEditTextchanged(const QString &text);
     void onComboBoxOutputTabEditTextChanged(const QString &text);
     void onSeparatorEditTextEdited(const QString &text);
