@@ -31,7 +31,7 @@ class ActionHandler final : public QObject
 {
     Q_OBJECT
 public:
-    explicit ActionHandler(NotificationDaemon *notificationDaemon, QWidget *parent);
+    explicit ActionHandler(NotificationDaemon *notificationDaemon, QObject *parent);
 
     int runningActionCount() const { return m_actions.size() - m_internalActions.size(); }
 
@@ -50,14 +50,7 @@ public:
 
     void terminateAction(int id);
 
-signals:
-    /** Emitted new action starts or ends. */
-    void runningActionsCountChanged();
-
 private:
-    /** Called after action was started (creates menu item to kill it). */
-    void actionStarted(Action *action);
-
     /** Delete finished action and its menu item. */
     void closeAction(Action *action);
 
