@@ -21,6 +21,7 @@
 #define CLIPBOARDSPY_H
 
 #include "common/clipboardmode.h"
+#include "platform/platformnativeinterface.h"
 
 #include <QObject>
 
@@ -28,20 +29,26 @@ class ClipboardSpy final : public QObject
 {
     Q_OBJECT
 public:
-    explicit ClipboardSpy(ClipboardMode mode);
+    explicit ClipboardSpy(ClipboardMode mode, const QByteArray &owner);
 
     /// Actively wait for clipboard/selection to change.
-    void wait(int ms = 2000);
+    void wait(int ms = 2000, int checkIntervalMs = 100);
+
+    bool setClipboardData(const QVariantMap &data);
+
+    QByteArray currentOwnerData() const;
+
+    void stop();
 
 signals:
     void changed();
+    void stopped();
 
 private:
-    void onChanged();
     bool check();
 
     ClipboardMode m_mode;
-    bool m_changed = false;
+    PlatformClipboardPtr m_clipboard;
     QByteArray m_oldOwnerData;
 };
 
