@@ -68,8 +68,6 @@ private:
 
     void onAddCommands(const QVector<Command> &commands);
 
-    void onClipboardChanged();
-
     void onCommandTextChanged(const QString &command);
 
     void onItemOrderListCommandsAddButtonClicked();
@@ -91,6 +89,8 @@ private:
 
     void updateIcon(int row);
 
+    QString commandsToPaste();
+
     Ui::CommandDialog *ui;
     Commands m_savedCommands;
 
