@@ -70,11 +70,18 @@ private:
 
     void updateWidgets();
 
+    void updateShowAdvanced();
+
+    void setShowAdvanced(bool showAdvanced);
+
     void emitIconChanged();
 
     QString description() const;
 
     Ui::CommandWidget *ui;
+    bool m_showAdvanced = true;
+    QString m_internalId;
+    bool m_isEditable = true;
 };
 
 #endif // COMMANDWIDGET_H
