@@ -126,7 +126,7 @@ private:
     void bind(const QString &optionKey, QSpinBox  *obj, int defaultValue);
     void bind(const QString &optionKey, QLineEdit *obj, const QString &defaultValue);
     void bind(const QString &optionKey, QComboBox *obj, int defaultValue);
-    void bind(const QString &optionKey, const QVariant &defaultValue);
+    void bind(const QString &optionKey, const QVariant &defaultValue, const char *description);
 
     void updateTabComboBoxes();
 
