@@ -126,6 +126,8 @@ private:
 
     void onPushButtonUpClicked();
     void onPushButtonDownClicked();
+    void onPushButtonTopClicked();
+    void onPushButtonBottomClicked();
     void onPushButtonRemoveClicked();
     void onPushButtonAddClicked();
 
@@ -133,6 +135,8 @@ private:
     void onListWidgetItemsItemSelectionChanged();
     void onListWidgetItemsItemChanged(QListWidgetItem *item);
 
+    void moveTab(int row, int targetRow);
+
     struct ItemWidgetPair {
         ItemWidgetPair() {}
         explicit ItemWidgetPair(const ItemPtr &item, bool checked)
