@@ -1,9 +1,12 @@
 #include "screen.h"
 
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QScreen>
 
+#if QT_VERSION < QT_VERSION_CHECK(5,11,0)
+#   include <QDesktopWidget>
+#endif
+
 namespace {
 
 QScreen *screenFromNumber(int i)
@@ -37,7 +40,7 @@ QRect screenGeometry(int i)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5,11,0)
     auto screen = screenFromNumber(i);
-    return screen ? screen->geometry() : QRect();
+    return screen ? screen->availableGeometry() : QRect();
 #else
     return QApplication::desktop()->screenGeometry(i);
 #endif
@@ -47,15 +50,7 @@ QRect screenAvailableGeometry(const QPoint &pos)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5,11,0)
     auto screen = QGuiApplication::screenAt(pos);
-    if (screen == nullptr) {
-        screen = screenFromNumber(0);
-        if (screen == nullptr)
-            return QRect();
-    }
-
-    const QRect g = screen->availableGeometry();
-    const qreal ratio = screen->devicePixelRatio();
-    return QRect(g.topLeft() * ratio, g.bottomRight() * ratio);
+    return screen ? screen->availableGeometry() : screenGeometry(0);
 #else
     return QApplication::desktop()->availableGeometry(pos);
 #endif
