@@ -145,7 +145,8 @@ int itemLabelPadding()
 QLabel *createLabel(const QString &objectName, QWidget *parent)
 {
     QLabel *label = new QLabel(parent);
-    label->setMargin(itemLabelPadding());
+    const int p = itemLabelPadding();
+    label->setContentsMargins({p,p,p,p});
     label->setObjectName(objectName);
 
     return label;
@@ -164,7 +165,7 @@ public:
         m_label->installEventFilter(this);
 
         m_layout->addWidget(m_label);
-        m_layout->setMargin(0);
+        m_layout->setContentsMargins({});
         m_layout->addStretch(1);
 
         updateFromItem(item);
@@ -342,18 +343,20 @@ void TabTree::setTabItemCount(const QString &tabName, const QString &itemCount)
     updateSize();
 }
 
-void TabTree::updateTabIcon(const QString &tabName)
+void TabTree::setTabIcon(QTreeWidgetItem *item, const QString &icon)
 {
-    QTreeWidgetItem *item = findTreeItem(tabName);
-    if (!item)
-        return;
-
-    const QIcon icon = getIconForTabName(tabName);
-    item->setIcon(0, icon);
+    item->setIcon(0, icon.isEmpty() ? QIcon() : iconFromFile(icon));
     updateItemSize(item);
     updateSize();
 }
 
+void TabTree::setTabIcon(const QString &tabName, const QString &icon)
+{
+    QTreeWidgetItem *item = findTreeItem(tabName);
+    if (item)
+        setTabIcon(item, icon);
+}
+
 void TabTree::insertTab(int index, const QString &path)
 {
     QStringList pathComponents = path.split('/');
@@ -390,9 +393,6 @@ void TabTree::insertTab(int index, const QString &path)
         item->setExpanded(true);
         item->setData(0, DataText, text);
 
-        const QIcon icon = getIconForTabName( getTabPath(item) );
-        item->setIcon(0, icon);
-
         labelItem(item);
     }
 
@@ -418,7 +418,7 @@ void TabTree::removeTab(int index)
     updateSize();
 }
 
-void TabTree::updateCollapsedTabs(QStringList *tabs) const
+void TabTree::updateCollapsedTabs(QList<QString> *tabs) const
 {
     tabs->clear();
     for ( QTreeWidgetItemIterator it(topLevelItem(0)); *it; ++it ) {
@@ -428,7 +428,7 @@ void TabTree::updateCollapsedTabs(QStringList *tabs) const
     }
 }
 
-void TabTree::setCollapsedTabs(const QStringList &collapsedPaths)
+void TabTree::setCollapsedTabs(const QList<QString> &collapsedPaths)
 {
     for (const auto &path : collapsedPaths) {
         QTreeWidgetItem *item = findTreeItem(path);
@@ -437,10 +437,13 @@ void TabTree::setCollapsedTabs(const QStringList &collapsedPaths)
     }
 }
 
-void TabTree::updateTabIcons()
+void TabTree::updateTabIcons(const QHash<QString, QString> &tabIcons)
 {
-    for ( QTreeWidgetItemIterator it(topLevelItem(0)); *it; ++it )
-        updateTabIcon( getTabPath(*it) );
+    for ( QTreeWidgetItemIterator it(topLevelItem(0)); *it; ++it ) {
+        const QString name = getTabPath(*it);
+        const QString icon = tabIcons.value(name);
+        setTabIcon(*it, icon);
+    }
 }
 
 void TabTree::nextTab()
