@@ -28,13 +28,10 @@
 #include <QApplication>
 #include <QDesktopServices>
 #include <QEvent>
-#include <QFont>
 #include <QMimeData>
 #include <QModelIndex>
 #include <QMouseEvent>
-#include <QPalette>
 #include <QTextEdit>
-#include <QTextFormat>
 #include <QUrl>
 #include <QWidget>
 
@@ -48,8 +45,7 @@ bool canMouseInteract(const QMouseEvent &event)
 } // namespace
 
 ItemWidget::ItemWidget(QWidget *widget)
-    : m_re()
-    , m_widget(widget)
+    : m_widget(widget)
 {
     Q_ASSERT(widget != nullptr);
 
@@ -66,15 +62,6 @@ ItemWidget::ItemWidget(QWidget *widget)
     widget->setAcceptDrops(false);
 }
 
-void ItemWidget::setHighlight(const QRegularExpression &re, const QFont &highlightFont,
-                              const QPalette &highlightPalette)
-{
-    if (m_re == re)
-        return;
-    m_re = re;
-    highlight(re, highlightFont, highlightPalette);
-}
-
 void ItemWidget::updateSize(QSize maximumSize, int idealWidth)
 {
     QWidget *w = widget();
@@ -200,6 +187,13 @@ QVariantList ItemScriptable::currentArguments()
     return arguments;
 }
 
+void ItemScriptable::throwError(const QString &message)
+{
+    QMetaObject::invokeMethod(
+                m_scriptable, "throwException", Qt::DirectConnection,
+                Q_ARG(QString, message) );
+}
+
 bool ItemSaverInterface::saveItems(const QString &, const QAbstractItemModel &, QIODevice *)
 {
     return false;
@@ -268,7 +262,7 @@ ItemSaverPtr ItemLoaderInterface::transformSaver(const ItemSaverPtr &saver, QAbs
     return saver;
 }
 
-bool ItemLoaderInterface::matches(const QModelIndex &, const QRegularExpression &) const
+bool ItemLoaderInterface::matches(const QModelIndex &, const ItemFilter &) const
 {
     return false;
 }
