@@ -1,18 +1,22 @@
 /*
     SPDX-FileCopyrightText: 2020 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2021 Méven Car <meven.car@enioka.com>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "waylandclipboard.h"
 
+#include <QBuffer>
 #include <QDebug>
+#include <QElapsedTimer>
 #include <QFile>
-#include <QFutureWatcher>
 #include <QGuiApplication>
-
+#include <QImageReader>
+#include <QImageWriter>
+#include <QMimeData>
+#include <QThread>
 #include <QtWaylandClient/QWaylandClientExtension>
-
 #include <qpa/qplatformnativeinterface.h>
 
 #include <errno.h>
@@ -22,6 +26,119 @@
 
 #include "qwayland-wlr-data-control-unstable-v1.h"
 
+static inline QString applicationQtXImageLiteral()
+{
+    return QStringLiteral("application/x-qt-image");
+}
+
+// copied from https://code.woboq.org/qt5/qtbase/src/gui/kernel/qinternalmimedata.cpp.html
+static QString utf8Text()
+{
+    return QStringLiteral("text/plain;charset=utf-8");
+}
+
+static QStringList imageMimeFormats(const QList<QByteArray> &imageFormats)
+{
+    QStringList formats;
+    formats.reserve(imageFormats.size());
+    for (const auto &format : imageFormats)
+        formats.append(QLatin1String("image/") + QLatin1String(format.toLower()));
+    // put png at the front because it is best
+    int pngIndex = formats.indexOf(QLatin1String("image/png"));
+    if (pngIndex != -1 && pngIndex != 0)
+        formats.move(pngIndex, 0);
+    return formats;
+}
+
+static inline QStringList imageReadMimeFormats()
+{
+    return imageMimeFormats(QImageReader::supportedImageFormats());
+}
+
+static inline QStringList imageWriteMimeFormats()
+{
+    return imageMimeFormats(QImageWriter::supportedImageFormats());
+}
+// end copied
+
+namespace {
+
+class SendThread : public QThread {
+public:
+    SendThread(int fd, const QByteArray &data)
+        : m_data(data)
+        , m_fd(fd)
+    {}
+
+protected:
+    void run() override {
+        QFile c;
+        if (c.open(m_fd, QFile::WriteOnly, QFile::AutoCloseHandle)) {
+            c.write(m_data);
+            c.close();
+        }
+    }
+
+private:
+    QByteArray m_data;
+    int m_fd;
+};
+
+class ReceiveThread : public QThread {
+public:
+    ReceiveThread(int fd)
+        : m_fd(fd)
+    {}
+
+    QByteArray data() const { return m_data; }
+
+protected:
+    void run() override {
+        QFile readPipe;
+        if (readPipe.open(m_fd, QIODevice::ReadOnly, QFile::AutoCloseHandle)) {
+            readData();
+            close(m_fd);
+        }
+    }
+
+private:
+    void readData() {
+        pollfd pfds[1];
+        pfds[0].fd = m_fd;
+        pfds[0].events = POLLIN;
+
+        while (true) {
+            const int ready = poll(pfds, 1, 1000);
+            if (ready < 0) {
+                if (errno != EINTR) {
+                    qWarning("DataControlOffer: poll() failed: %s", strerror(errno));
+                    return;
+                }
+            } else if (ready == 0) {
+                qWarning("DataControlOffer: timeout reading from pipe");
+                return;
+            } else {
+                char buf[4096];
+                int n = read(m_fd, buf, sizeof buf);
+
+                if (n < 0) {
+                    qWarning("DataControlOffer: read() failed: %s", strerror(errno));
+                    return;
+                } else if (n == 0) {
+                    return;
+                } else if (n > 0) {
+                    m_data.append(buf, n);
+                }
+            }
+        }
+    }
+
+    QByteArray m_data;
+    int m_fd;
+};
+
+} // namespace
+
 class DataControlDeviceManager : public QWaylandClientExtensionTemplate<DataControlDeviceManager>
         , public QtWayland::zwlr_data_control_manager_v1
 {
@@ -32,10 +149,22 @@ public:
     {
     }
 
+    void instantiate()
+    {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
+        initialize();
+#else
+        // QWaylandClientExtensionTemplate invokes this with a QueuedConnection but we want shortcuts
+        // to be have access to data_control immediately.
+        QMetaObject::invokeMethod(this, "addRegistryListener");
+#endif
+    }
+
     ~DataControlDeviceManager()
     {
-        if ( isInitialized() )
+        if (isInitialized()) {
             destroy();
+        }
     }
 };
 
@@ -59,9 +188,44 @@ public:
         return m_receivedFormats;
     }
 
-    bool hasFormat(const QString &format) const override
+    bool containsImageData() const
     {
-        return m_receivedFormats.contains(format);
+        if (m_receivedFormats.contains(applicationQtXImageLiteral())) {
+            return true;
+        }
+        const auto formats = imageReadMimeFormats();
+        for (const auto &receivedFormat : m_receivedFormats) {
+            if (formats.contains(receivedFormat)) {
+                return true;
+            }
+        }
+        return false;
+    }
+
+    bool hasFormat(const QString &mimeType) const override
+    {
+        if (mimeType == QStringLiteral("text/plain") && m_receivedFormats.contains(utf8Text())) {
+            return true;
+        }
+        if (m_receivedFormats.contains(mimeType)) {
+            return true;
+        }
+
+        // If we have image data
+        if (containsImageData()) {
+            // is the requested output mimeType supported ?
+            const QStringList imageFormats = imageWriteMimeFormats();
+            for (const QString &imageFormat : imageFormats) {
+                if (imageFormat == mimeType) {
+                    return true;
+                }
+            }
+            if (mimeType == applicationQtXImageLiteral()) {
+                return true;
+            }
+        }
+
+        return false;
     }
 
 protected:
@@ -70,19 +234,48 @@ protected:
         m_receivedFormats << mime_type;
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
     QVariant retrieveData(const QString &mimeType, QVariant::Type type) const override;
+#else
+    QVariant retrieveData(const QString &mimetype, QMetaType type) const override;
+#endif
 
 private:
-    static bool readData(int fd, QByteArray &data);
     QStringList m_receivedFormats;
 };
 
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
 QVariant DataControlOffer::retrieveData(const QString &mimeType, QVariant::Type type) const
+#else
+QVariant DataControlOffer::retrieveData(const QString &mimeType, QMetaType type) const
+#endif
 {
-    if (!hasFormat(mimeType)) {
-        return QVariant();
+    Q_UNUSED(type);
+
+    QString mime;
+    if (!m_receivedFormats.contains(mimeType)) {
+        if (mimeType == QStringLiteral("text/plain") && m_receivedFormats.contains(utf8Text())) {
+            mime = utf8Text();
+        } else if (mimeType == applicationQtXImageLiteral()) {
+            const auto writeFormats = imageWriteMimeFormats();
+            for (const auto &receivedFormat : m_receivedFormats) {
+                if (writeFormats.contains(receivedFormat)) {
+                    mime = receivedFormat;
+                    break;
+                }
+            }
+            if (mime.isEmpty()) {
+                // default exchange format
+                mime = QStringLiteral("image/png");
+            }
+        }
+
+        if (mime.isEmpty()) {
+            return QVariant();
+        }
+    } else {
+        mime = mimeType;
     }
-    Q_UNUSED(type)
 
     int pipeFds[2];
     if (pipe(pipeFds) != 0) {
@@ -90,7 +283,7 @@ QVariant DataControlOffer::retrieveData(const QString &mimeType, QVariant::Type
     }
 
     auto t = const_cast<DataControlOffer *>(this);
-    t->receive(mimeType, pipeFds[1]);
+    t->receive(mime, pipeFds[1]);
 
     close(pipeFds[1]);
 
@@ -101,53 +294,24 @@ QVariant DataControlOffer::retrieveData(const QString &mimeType, QVariant::Type
      * However this isn't actually any worse than X.
      */
 
-    QPlatformNativeInterface *native = qApp->platformNativeInterface();
+    QPlatformNativeInterface *native = qGuiApp->platformNativeInterface();
     auto display = static_cast<struct ::wl_display *>(native->nativeResourceForIntegration("wl_display"));
     wl_display_flush(display);
 
-    QFile readPipe;
-    if (readPipe.open(pipeFds[0], QIODevice::ReadOnly, QFile::AutoCloseHandle)) {
-        QByteArray data;
-        if (readData(pipeFds[0], data)) {
-            return data;
-        }
-        close(pipeFds[0]);
-    }
-    return QVariant();
-}
+    ReceiveThread thread(pipeFds[0]);
+    thread.start();
+    while (thread.isRunning())
+        QCoreApplication::processEvents();
+    const auto data = thread.data();
 
-// reads data from a file descriptor with a timeout of 1 second
-// true if data is read successfully
-bool DataControlOffer::readData(int fd, QByteArray &data)
-{
-    pollfd pfds[1];
-    pfds[0].fd = fd;
-    pfds[0].events = POLLIN;
-
-    while (true) {
-        const int ready = poll(pfds, 1, 1000);
-        if (ready < 0) {
-            if (errno != EINTR) {
-                qWarning("DataControlOffer: poll() failed: %s", strerror(errno));
-                return false;
-            }
-        } else if (ready == 0) {
-            qWarning("DataControlOffer: timeout reading from pipe");
-            return false;
-        } else {
-            char buf[4096];
-            int n = read(fd, buf, sizeof buf);
-
-            if (n < 0) {
-                qWarning("DataControlOffer: read() failed: %s", strerror(errno));
-                return false;
-            } else if (n == 0) {
-                return true;
-            } else if (n > 0) {
-                data.append(buf, n);
-            }
+    if (!data.isEmpty() && mimeType == applicationQtXImageLiteral()) {
+        QImage img = QImage::fromData(data, mime.mid(mime.indexOf(QLatin1Char('/')) + 1).toLatin1().toUpper().data());
+        if (!img.isNull()) {
+            return img;
         }
     }
+
+    return data;
 }
 
 class DataControlSource : public QObject, public QtWayland::zwlr_data_control_source_v1
@@ -155,7 +319,7 @@ class DataControlSource : public QObject, public QtWayland::zwlr_data_control_so
     Q_OBJECT
 public:
     DataControlSource(struct ::zwlr_data_control_source_v1 *id, QMimeData *mimeData);
-    DataControlSource();
+
     ~DataControlSource()
     {
         if ( isInitialized() )
@@ -185,18 +349,27 @@ DataControlSource::DataControlSource(struct ::zwlr_data_control_source_v1 *id, Q
     : QtWayland::zwlr_data_control_source_v1(id)
     , m_mimeData(mimeData)
 {
-    for (const QString &format : mimeData->formats()) {
+    const auto formats = mimeData->formats();
+    for (const QString &format : formats) {
         offer(format);
     }
     if (mimeData->hasText()) {
         // ensure GTK applications get this mimetype to avoid them discarding the offer
         offer(QStringLiteral("text/plain;charset=utf-8"));
     }
+
+    if (mimeData->hasImage()) {
+        const QStringList imageFormats = imageWriteMimeFormats();
+        for (const QString &imageFormat : imageFormats) {
+            if (!formats.contains(imageFormat)) {
+                offer(imageFormat);
+            }
+        }
+    }
 }
 
 void DataControlSource::zwlr_data_control_source_v1_send(const QString &mime_type, int32_t fd)
 {
-    QFile c;
     QString send_mime_type = mime_type;
     if( send_mime_type == QStringLiteral("text/plain;charset=utf-8")
         && !m_mimeData->hasFormat(QStringLiteral("text/plain;charset=utf-8")) )
@@ -204,10 +377,31 @@ void DataControlSource::zwlr_data_control_source_v1_send(const QString &mime_typ
         // if we get a request on the fallback mime, send the data from the original mime type
         send_mime_type = QStringLiteral("text/plain");
     }
-    if (c.open(fd, QFile::WriteOnly, QFile::AutoCloseHandle)) {
-        c.write(m_mimeData->data(send_mime_type));
-        c.close();
+
+    QByteArray ba;
+    if (m_mimeData->hasImage()) {
+        // adapted from QInternalMimeData::renderDataHelper
+        if (mime_type == applicationQtXImageLiteral()) {
+            QImage image = qvariant_cast<QImage>(m_mimeData->imageData());
+            QBuffer buf(&ba);
+            buf.open(QBuffer::WriteOnly);
+            // would there not be PNG ??
+            image.save(&buf, "PNG");
+
+        } else if (mime_type.startsWith(QLatin1String("image/"))) {
+            QImage image = qvariant_cast<QImage>(m_mimeData->imageData());
+            QBuffer buf(&ba);
+            buf.open(QBuffer::WriteOnly);
+            image.save(&buf, mime_type.mid(mime_type.indexOf(QLatin1Char('/')) + 1).toLatin1().toUpper().data());
+        }
+        // end adapted
+    } else {
+        ba = m_mimeData->data(send_mime_type);
     }
+
+    auto thread = new SendThread(fd, m_mimeData->data(send_mime_type));
+    connect(thread, &QThread::finished, thread, &QObject::deleteLater);
+    thread->start();
 }
 
 void DataControlSource::zwlr_data_control_source_v1_cancelled()
@@ -261,9 +455,9 @@ Q_SIGNALS:
 protected:
     void zwlr_data_control_device_v1_data_offer(struct ::zwlr_data_control_offer_v1 *id) override
     {
-        new DataControlOffer(id);
         // this will become memory managed when we retrieve the selection event
         // a compositor calling data_offer without doing that would be a bug
+        new DataControlOffer(id);
     }
 
     void zwlr_data_control_device_v1_selection(struct ::zwlr_data_control_offer_v1 *id) override
@@ -272,14 +466,14 @@ protected:
             m_receivedSelection.reset();
         } else {
 #if QT_VERSION >= QT_VERSION_CHECK(5,12,5)
-            auto deriv = QtWayland::zwlr_data_control_offer_v1::fromObject(id);
+            auto derivated = QtWayland::zwlr_data_control_offer_v1::fromObject(id);
 #else
-            auto deriv = static_cast<QtWayland::zwlr_data_control_offer_v1 *>(zwlr_data_control_offer_v1_get_user_data(id));
+            auto derivated = static_cast<QtWayland::zwlr_data_control_offer_v1 *>(zwlr_data_control_offer_v1_get_user_data(id));
 #endif
-            auto offer = dynamic_cast<DataControlOffer *>(deriv); // dynamic because of the dual inheritance
+            auto offer = dynamic_cast<DataControlOffer *>(derivated); // dynamic because of the dual inheritance
             m_receivedSelection.reset(offer);
         }
-        emit receivedSelectionChanged();
+        Q_EMIT receivedSelectionChanged();
     }
 
     void zwlr_data_control_device_v1_primary_selection(struct ::zwlr_data_control_offer_v1 *id) override
@@ -288,14 +482,14 @@ protected:
             m_receivedPrimarySelection.reset();
         } else {
 #if QT_VERSION >= QT_VERSION_CHECK(5,12,5)
-            auto deriv = QtWayland::zwlr_data_control_offer_v1::fromObject(id);
+            auto derivated = QtWayland::zwlr_data_control_offer_v1::fromObject(id);
 #else
-            auto deriv = static_cast<QtWayland::zwlr_data_control_offer_v1 *>(zwlr_data_control_offer_v1_get_user_data(id));
+            auto derivated = static_cast<QtWayland::zwlr_data_control_offer_v1 *>(zwlr_data_control_offer_v1_get_user_data(id));
 #endif
-            auto offer = dynamic_cast<DataControlOffer *>(deriv); // dynamic because of the dual inheritance
+            auto offer = dynamic_cast<DataControlOffer *>(derivated); // dynamic because of the dual inheritance
             m_receivedPrimarySelection.reset(offer);
         }
-        emit receivedPrimarySelectionChanged();
+        Q_EMIT receivedPrimarySelectionChanged();
     }
 
 private:
@@ -332,7 +526,7 @@ void DataControlDevice::setPrimarySelection(std::unique_ptr<DataControlSource> s
 }
 
 WaylandClipboard::WaylandClipboard(QObject *parent)
-    : SystemClipboard(parent)
+    : QObject(parent)
     , m_manager(new DataControlDeviceManager)
 {
     connect(m_manager.get(), &DataControlDeviceManager::activeChanged, this, [this]() {
@@ -349,23 +543,44 @@ WaylandClipboard::WaylandClipboard(QObject *parent)
             m_device.reset(new DataControlDevice(m_manager->get_data_device(seat)));
 
             connect(m_device.get(), &DataControlDevice::receivedSelectionChanged, this, [this]() {
-                emit changed(QClipboard::Clipboard);
+                Q_EMIT changed(QClipboard::Clipboard);
             });
             connect(m_device.get(), &DataControlDevice::selectionChanged, this, [this]() {
-                emit changed(QClipboard::Clipboard);
+                Q_EMIT changed(QClipboard::Clipboard);
             });
 
             connect(m_device.get(), &DataControlDevice::receivedPrimarySelectionChanged, this, [this]() {
-                emit changed(QClipboard::Selection);
+                Q_EMIT changed(QClipboard::Selection);
             });
             connect(m_device.get(), &DataControlDevice::primarySelectionChanged, this, [this]() {
-                emit changed(QClipboard::Selection);
+                Q_EMIT changed(QClipboard::Selection);
             });
 
         } else {
             m_device.reset();
         }
     });
+
+    m_manager->instantiate();
+}
+
+WaylandClipboard *WaylandClipboard::createInstance()
+{
+    qInfo() << "Using Wayland clipboard access";
+    auto clipboard = new WaylandClipboard(qApp);
+
+    QElapsedTimer timer;
+    timer.start();
+    while ( !clipboard->isActive() && timer.elapsed() < 5000 ) {
+        QCoreApplication::processEvents();
+    }
+    if ( timer.elapsed() > 100 ) {
+        qWarning() << "Activating Wayland clipboard took" << timer.elapsed() << "ms";
+    }
+    if ( !clipboard->isActive() ) {
+        qCritical() << "Failed to activate Wayland clipboard";
+    }
+    return clipboard;
 }
 
 void WaylandClipboard::setMimeData(QMimeData *mime, QClipboard::Mode mode)
@@ -403,11 +618,31 @@ const QMimeData *WaylandClipboard::mimeData(QClipboard::Mode mode) const
 
     // return our locally set selection if it's not cancelled to avoid copying data to ourselves
     if (mode == QClipboard::Clipboard) {
-        return m_device->selection() ? m_device->selection() : m_device->receivedSelection();
+        if (m_device->selection()) {
+            return m_device->selection();
+        }
+        return m_device->receivedSelection();
     } else if (mode == QClipboard::Selection) {
-        return m_device->primarySelection() ? m_device->primarySelection() : m_device->receivedPrimarySelection();
+        if (m_device->primarySelection()) {
+            return m_device->primarySelection();
+        }
+        return m_device->receivedPrimarySelection();
     }
     return nullptr;
 }
 
+bool WaylandClipboard::isSelectionSupported() const
+{
+    return m_device && zwlr_data_control_device_v1_get_version(m_device->object())
+            >= ZWLR_DATA_CONTROL_DEVICE_V1_SET_PRIMARY_SELECTION_SINCE_VERSION;
+}
+
+WaylandClipboard *WaylandClipboard::instance()
+{
+    static WaylandClipboard *clipboard = createInstance();
+    return clipboard;
+}
+
+WaylandClipboard::~WaylandClipboard() = default;
+
 #include "waylandclipboard.moc"
